###### Disentangling relationships between physiology, morphology, diet, and gut microbial diversity in American Kestrel nestlings ######
# Written by: Jennifer L. Houtz
# Manuscript ID: JAV12893
# Alpha Diversity Statistical Analysis and Figures R script

# This code is used to conduct statistical analyses on alpha diversity metrics (Shannon, Chao1, and Faith's PD)
# and phylum-level analyses

##### Data Preparation #####

# Load packages

pacman::p_load("nlme", "ggplot2", "phyloseq",
               "vegan", "devtools", "sjPlot", "here", "car")

# Upload metadata
AMKE <- read.csv("kestrel_micro_metadata.csv", header = TRUE, sep = ",")
summary(AMKE)

# Look at structure and change variables to appropriate data type

str(AMKE)
names(AMKE)

AMKE$nest_year <- as.factor(AMKE$nest_year)
AMKE$sex <- as.factor(AMKE$sex)
AMKE$age <- as.factor(AMKE$age)
AMKE$chick_ID <- as.factor(AMKE$chick_ID)
AMKE$year <- as.factor(AMKE$year)

#####Check normality of alpha diversity metrics#####
# Shapiro test of W>0.95 is normal, look at distribution
# Log transform if not normal

# Normality test - Shannon diversity

shapiro.test(AMKE$shannon)
hist(AMKE$shannon)
#normal

# Normality test - Chao1 diversity

shapiro.test(AMKE$chao1)
hist(AMKE$chao1)
#not normal

AMKE$logchao=log(AMKE$chao1)
hist(AMKE$logchao)
#looks much more normal now

shapiro.test(AMKE$logchao)
#log transformed data is better

# Normality test - Faith's PD diversity

shapiro.test(AMKE$faith_pd)
hist(AMKE$faith_pd)
#not normal

AMKE$logfaith_pd=log(AMKE$faith_pd)
hist(AMKE$logfaith_pd)
#looks much more normal now

shapiro.test(AMKE$logfaith_pd)
#log transformed data is better

# Create sampling year subsets

# Subset to only 2018
amke18<-subset(AMKE, year ==2018)
table(amke18$year)

# Subset to only 2019
amke19<-subset(AMKE, year ==2019)
table(amke19$year)

# Create age subsets

# 7 days old
amke7<-subset(AMKE, age ==7)
table(amke7$age)

# 14 days old
amke14<-subset(AMKE, age ==14)
table(amke14$age)

# 21 days old
amke21<-subset(AMKE, age ==21)
table(amke21$age)

##### Linear mixed models - age, sex, and year #####

##### Age, sex, and year - shannon #####

# Sex*age interaction, year as separate fixed effect
mod_sex_ageint_shannon <- lme(fixed = shannon ~ age*sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sex_ageint_shannon)
anova(mod_sex_ageint_shannon)
#not significant sex*age

# Sex, age, and year as separate fixed effects
mod_sex_age_shannon <- lme(fixed = shannon ~ age + sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sexage_shannon)
anova(mod_sexage_shannon)
tab_model(mod_sexage_shannon)

# Check model conditions
hist(resid(mod_sexage_shannon))
plot(mod_sexage_shannon)
car::qqPlot(mod_sexage_shannon, 
       simulate = FALSE,
       id = FALSE)

##### Age, sex, and year - chao1 log transformed #####

# Age*sex interaction, year as separate fixed effect
mod_sex_ageint_chao1 <- lme(fixed = logchao ~ age*sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sex_ageint_chao1)
anova(mod_sex_ageint_chao1)
##not significant sex*age. but year is significant

# Age, sex, and year as separate fixed effects
mod_sex_age_chao1 <- lme(fixed = logchao ~ age + sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sex_age_chao1)
anova(mod_sex_age_chao1)
tab_model(mod_sex_age_chao1)

# Check model conditions
hist(resid(mod_sex_age_chao1))
plot(mod_sex_age_chao1)
car::qqPlot(mod_sex_age_chao1, 
            simulate = FALSE,
            id = FALSE)

##### Age, sex, and year - faith's pd log transformed #####

# Age*sex interaction, year as separate fixed effect
mod_sex_ageint_faithpd <- lme(fixed = logfaith_pd ~ age*sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sex_ageint_faithpd )
anova(mod_sex_ageint_faithpd )
tab_model(mod_sex_ageint_faithpd)
#not significant sex*age. but year is significant

# Age, sex, and year as separate fixed effects
mod_sex_age_faithpd  <- lme(fixed = logfaith_pd ~ age + sex + year, random=~1|nest/chick_ID, na.action=na.omit, data=AMKE)
summary(mod_sex_age_faithpd)
anova(mod_sex_age_faithpd)
tab_model(mod_sex_age_faithpd)

# Check model conditions
hist(resid(mod_sex_age_faithpd))
plot(mod_sex_age_faithpd)
car::qqPlot(mod_sex_age_faithpd, 
            simulate = FALSE,
            id = FALSE)

##### Linear mixed models - diet diversity day 21 only #####

##### Diet diversity day 21 - Shannon #####

mod_diet_shannon <- lme(fixed = shannon ~ Hmaxmass, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_diet_shannon)
anova(mod_diet_shannon)
tab_model(mod_diet_shannon)

# Check model conditions
hist(resid(mod_diet_shannon))
plot(mod_diet_shannon)
car::qqPlot(mod_diet_shannon, 
            simulate = FALSE,
            id = FALSE)

##### Diet diversity day 21 - chao1 log transformed #####

mod_diet_chao1 <- lme(fixed = logchao ~ Hmaxmass, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_diet_chao1)
anova(mod_diet_chao1)
tab_model(mod_diet_chao1)

# Check model conditions
hist(resid(mod_diet_chao1))
plot(mod_diet_chao1)
car::qqPlot(mod_diet_chao1, 
            simulate = FALSE,
            id = FALSE)

##### Diet diversity day 21 - faith's pd log transformed #####

mod_diet_faithpd <- lme(fixed = logfaith_pd ~ Hmaxmass, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_diet_faithpd)
anova(mod_diet_faithpd)
tab_model(mod_diet_faithpd)

# Check model conditions
hist(resid(mod_diet_faithpd))
plot(mod_diet_faithpd)
car::qqPlot(mod_diet_faithpd, 
            simulate = FALSE,
            id = FALSE)

##### Prey types day 21 - shannon #####

mod_prey_shannon <- lme(fixed = shannon ~ mammalpmass + songbirdpmass + arthropodpmass+ annelidpmass, 
              random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_prey_shannon)
anova(mod_prey_shannon)
tab_model(mod_prey_shannon)

# Check model conditions
hist(resid(mod_prey_shannon))
plot(mod_prey_shannon)
car::qqPlot(mod_prey_shannon, 
            simulate = FALSE,
            id = FALSE)

##### Prey types day 21 - chao log-transformed #####

mod_prey_chao1 <- lme(fixed = logchao ~ mammalpmass + songbirdpmass + arthropodpmass+ annelidpmass, 
              random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_prey_chao1)
anova(mod_prey_chao1)
tab_model(mod_prey_chao1)

# Check model conditions
hist(resid(mod_prey_chao1))
plot(mod_prey_chao1)
car::qqPlot(mod_prey_chao1, 
            simulate = FALSE,
            id = FALSE)

##### Prey types day 21 - faith's pd log-transformed #####

mod_prey_faithpd <- lme(fixed = logfaith_pd ~ mammalpmass + songbirdpmass + arthropodpmass+ annelidpmass, 
              random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_prey_faithpd)
anova(mod_prey_faithpd)
tab_model(mod_prey_faithpd)

# Check model conditions
hist(resid(mod_prey_faithpd))
plot(mod_prey_faithpd)
car::qqPlot(mod_prey_faithpd, 
            simulate = FALSE,
            id = FALSE)

##### Nestling mass - contemporary comparisons #####
# Control for sex in day 14 and 21
# Control for sampling year in chao1 models

##### Mass day 7 - shannon day 7 #####
mod_mass7_shannon7 <- lme(fixed = d7mass ~ shannon, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass7_shannon7)
anova(mod_mass7_shannon7)
tab_model(mod_mass7_shannon7)

# Check model conditions
hist(resid(mod_mass7_shannon7))
plot(mod_mass7_shannon7)
car::qqPlot(mod_mass7_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - shannon day 14#####
mod_mass14_shannon14 <- lme(fixed = d14mass ~ shannon + sex, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_mass14_shannon14)
anova(mod_mass14_shannon14)
tab_model(mod_mass14_shannon14)

# Check model conditions
hist(resid(mod_mass14_shannon14))
plot(mod_mass14_shannon14)
car::qqPlot(mod_mass14_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - shannon day 21#####
mod_mass21_shannon21 <- lme(fixed = d21mass ~ shannon + sex, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_mass21_shannon21)
anova(mod_mass21_shannon21)
tab_model(mod_mass21_shannon21)

# Check model conditions
hist(resid(mod_mass21_shannon21))
plot(mod_mass21_shannon21)
car::qqPlot(mod_mass21_shannon21, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 7 - chao1 day 7#####
mod_mass7_chao7 <- lme(fixed = d7mass ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_mass7_chao7)
anova(mod_mass7_chao7)
tab_model(mod_mass7_chao7)

# Check model conditions
hist(resid(mod_mass7_chao7))
plot(mod_mass7_chao7)
car::qqPlot(mod_mass7_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - chao1 day 14#####
mod_mass14_chao14 <- lme(fixed = d14mass ~ logchao + sex + year, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_mass14_chao14 )
anova(mod_mass14_chao14 )
tab_model(mod_mass14_chao14 )

# Check model conditions
hist(resid(mod_mass14_chao14))
plot(mod_mass14_chao14)
car::qqPlot(mod_mass14_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - chao1 day 21#####
mod_mass21_chao21 <- lme(fixed = d21mass ~ logchao + sex + year, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_mass21_chao21)
anova(mod_mass21_chao21)
tab_model(mod_mass21_chao21)

# Check model conditions
hist(resid(mod_mass21_chao21))
plot(mod_mass21_chao21)
car::qqPlot(mod_mass21_chao21, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 7 - faith's pd day 7#####
mod_mass7_faithpd7 <- lme(fixed = d7mass ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_mass7_faithpd7)
anova(mod_mass7_faithpd7)
tab_model(mod_mass7_faithpd7)

# Check model conditions
hist(resid(mod_mass7_faithpd7))
plot(mod_mass7_faithpd7)
car::qqPlot(mod_mass7_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - faith's pd day 14#####
mod_mass14_faithpd14 <- lme(fixed = d14mass ~ logfaith_pd + sex, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_mass14_faithpd14)
anova(mod_mass14_faithpd14)
tab_model(mod_mass14_faithpd14)

# Check model conditions
hist(resid(mod_mass14_faithpd14))
plot(mod_mass14_faithpd14)
car::qqPlot(mod_mass14_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - faith's pd day 21#####
mod_mass21_faithpd21 <- lme(fixed = d21mass ~ logfaith_pd + sex, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_mass21_faithpd21)
anova(mod_mass21_faithpd21)
tab_model(mod_mass21_faithpd21)

# Check model conditions
hist(resid(mod_mass21_faithpd21))
plot(mod_mass21_faithpd21)
car::qqPlot(mod_mass21_faithpd21, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 7 - Firmicutes day 7#####
mod_mass7_firm7 <- lme(fixed = d7mass ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_mass7_firm7)
anova(mod_mass7_firm7)
tab_model(mod_mass7_firm7)

# Check model conditions
hist(resid(mod_mass7_firm7))
plot(mod_mass7_firm7)
car::qqPlot(mod_mass7_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - Firmicutes day 14#####
mod_mass14_firm14 <- lme(fixed = d14mass ~ Firmicutes + sex, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_mass14_firm14)
anova(mod_mass14_firm14)
tab_model(mod_mass14_firm14)

# Check model conditions
hist(resid(mod_mass14_firm14))
plot(mod_mass14_firm14)
car::qqPlot(mod_mass14_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - Firmicutes day 21#####
mod_mass21_firm21 <- lme(fixed = d21mass ~ Firmicutes + sex, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_mass21_firm21)
anova(mod_mass21_firm21)
tab_model(mod_mass21_firm21)

# Check model conditions
hist(resid(mod_mass21_firm21))
plot(mod_mass21_firm21)
car::qqPlot(mod_mass21_firm21, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 7 - Proteobacteria day 7#####
mod_mass7_prot7 <- lme(fixed = d7mass ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_mass7_prot7)
anova(mod_mass7_prot7)
tab_model(mod_mass7_prot7)

# Check model conditions
hist(resid(mod_mass7_prot7))
plot(mod_mass7_prot7)
car::qqPlot(mod_mass7_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - Proteobacteria day 14#####
mod_mass14_prot14 <- lme(fixed = d14mass ~ Proteobacteria + sex, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_mass14_prot14)
anova(mod_mass14_prot14)
tab_model(mod_mass14_prot14)

# Check model conditions
hist(resid(mod_mass14_prot14))
plot(mod_mass14_prot14)
car::qqPlot(mod_mass14_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - Proteobacteria day 21#####
mod_mass21_prot21 <- lme(fixed = d21mass ~ Proteobacteria + sex, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_mass21_prot21)
anova(mod_mass21_prot21)
tab_model(mod_mass21_prot21)

# Check model conditions
hist(resid(mod_mass21_prot21))
plot(mod_mass21_prot21)
car::qqPlot(mod_mass21_prot21, 
            simulate = FALSE,
            id = FALSE)

##### Nestling mass - time-lagged comparisons #####

##### Mass day 14 - shannon day 7 #####
mod_mass14_shannon7 <- lme(fixed = d14mass ~ shannon + d7mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass14_shannon7)
anova(mod_mass14_shannon7)
tab_model(mod_mass14_shannon7)

# Check model conditions
hist(resid(mod_mass14_shannon7))
plot(mod_mass14_shannon7)
car::qqPlot(mod_mass14_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - shannon day 14 #####
mod_mass21_shannon14 <- lme(fixed = d21mass ~ shannon + d14mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke14)
summary(mod_mass21_shannon14)
anova(mod_mass21_shannon14)
tab_model(mod_mass21_shannon14)

# Check model conditions
hist(resid(mod_mass21_shannon14))
plot(mod_mass21_shannon14)
car::qqPlot(mod_mass21_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - chao1 day 7 #####
mod_mass14_chao7 <- lme(fixed = d14mass ~ logchao + d7mass + sex + year, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass14_chao7)
anova(mod_mass14_chao7)
tab_model(mod_mass14_chao7)

# Check model conditions
hist(resid(mod_mass14_chao7))
plot(mod_mass14_chao7)
car::qqPlot(mod_mass14_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - chao1 day 14 #####
mod_mass21_chao14 <- lme(fixed = d21mass ~ logchao + d14mass + sex + year, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke14)
summary(mod_mass21_chao14)
anova(mod_mass21_chao14)
tab_model(mod_mass21_chao14)

# Check model conditions
hist(resid(mod_mass21_chao14))
plot(mod_mass21_chao14)
car::qqPlot(mod_mass21_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - faith's pd day 7 #####
mod_mass14_faithpd7 <- lme(fixed = d14mass ~ logfaith_pd + d7mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass14_faithpd7)
anova(mod_mass14_faithpd7)
tab_model(mod_mass14_faithpd7)

# Check model conditions
hist(resid(mod_mass14_faithpd7))
plot(mod_mass14_faithpd7)
car::qqPlot(mod_mass14_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - faith's pd day 14 #####
mod_mass21_faithpd14 <- lme(fixed = d21mass ~ logfaith_pd + d14mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke14)
summary(mod_mass21_faithpd14)
anova(mod_mass21_faithpd14)
tab_model(mod_mass21_faithpd14)

# Check model conditions
hist(resid(mod_mass21_faithpd14))
plot(mod_mass21_faithpd14)
car::qqPlot(mod_mass21_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - Firmicutes day 7 #####
mod_mass14_firm7 <- lme(fixed = d14mass ~ Firmicutes + d7mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass14_firm7)
anova(mod_mass14_firm7)
tab_model(mod_mass14_firm7)

# Check model conditions
hist(resid(mod_mass14_firm7))
plot(mod_mass14_firm7)
car::qqPlot(mod_mass14_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - Firmicutes day 14 #####
mod_mass21_firm14 <- lme(fixed = d21mass ~ Firmicutes + d14mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke14)
summary(mod_mass21_firm14)
anova(mod_mass21_firm14)
tab_model(mod_mass21_firm14)

# Check model conditions
hist(resid(mod_mass21_firm14))
plot(mod_mass21_firm14)
car::qqPlot(mod_mass21_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 14 - Proteobacteria day 7 #####
mod_mass14_prot7 <- lme(fixed = d14mass ~ Proteobacteria + d7mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke7)
summary(mod_mass14_prot7)
anova(mod_mass14_prot7)
tab_model(mod_mass14_prot7)

# Check model conditions
hist(resid(mod_mass14_prot7))
plot(mod_mass14_prot7)
car::qqPlot(mod_mass14_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Mass day 21 - Proteobacteria day 14 #####
mod_mass21_prot14 <- lme(fixed = d21mass ~ Proteobacteria + d14mass + sex, random=~1|nest_year/chick_ID, na.action=na.omit, data=amke14)
summary(mod_mass21_prot14)
anova(mod_mass21_prot14)
tab_model(mod_mass21_prot14)

# Check model conditions
hist(resid(mod_mass21_prot14))
plot(mod_mass21_prot14)
car::qqPlot(mod_mass21_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Nestling physiology - contemporary comparisons #####

##### Glucose day 7 - shannon day 7#####
mod_glucose7_shannon7 <- lme(fixed = d7glucose ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose7_shannon7)
anova(mod_glucose7_shannon7)
tab_model(mod_glucose7_shannon7)

# Check model conditions
hist(resid(mod_glucose7_shannon7))
plot(mod_glucose7_shannon7)
car::qqPlot(mod_glucose7_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - shannon day 14#####
mod_glucose14_shannon14 <- lme(fixed = d14glucose ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose14_shannon14)
anova(mod_glucose14_shannon14)
tab_model(mod_glucose14_shannon14)

# Check model conditions
hist(resid(mod_glucose14_shannon14))
plot(mod_glucose14_shannon14)
car::qqPlot(mod_glucose14_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - shannon day 21#####
mod_glucose21_shannon21 <- lme(fixed = d21glucose ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_glucose21_shannon21)
anova(mod_glucose21_shannon21)
tab_model(mod_glucose21_shannon21)

# Check model conditions
hist(resid(mod_glucose21_shannon21))
plot(mod_glucose21_shannon21)
car::qqPlot(mod_glucose21_shannon21, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 7 - chao1 day 7#####
mod_glucose7_chao7 <- lme(fixed = d7glucose ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose7_chao7)
anova(mod_glucose7_chao7)
tab_model(mod_glucose7_chao7)

# Check model conditions
hist(resid(mod_glucose7_chao7))
plot(mod_glucose7_chao7)
car::qqPlot(mod_glucose7_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - chao1 day 14#####
mod_glucose14_chao14 <- lme(fixed = d14glucose ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose14_chao14)
anova(mod_glucose14_chao14)
tab_model(mod_glucose14_chao14)

# Check model conditions
hist(resid(mod_glucose14_chao14))
plot(mod_glucose14_chao14)
car::qqPlot(mod_glucose14_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - chao1 day 21#####
mod_glucose21_chao21 <- lme(fixed = d21glucose ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_glucose21_chao21)
anova(mod_glucose21_chao21)
tab_model(mod_glucose21_chao21)

# Check model conditions
hist(resid(mod_glucose21_chao21))
plot(mod_glucose21_chao21)
car::qqPlot(mod_glucose21_chao21, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 7 - faith's pd day 7#####
mod_glucose7_faithpd7 <- lme(fixed = d7glucose ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose7_faithpd7)
anova(mod_glucose7_faithpd7)
tab_model(mod_glucose7_faithpd7)

# Check model conditions
hist(resid(mod_glucose7_faithpd7))
plot(mod_glucose7_faithpd7)
car::qqPlot(mod_glucose7_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - faith's pd day 14#####
mod_glucose14_faithpd14 <- lme(fixed = d14glucose ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose14_faithpd14)
anova(mod_glucose14_faithpd14)
tab_model(mod_glucose14_faithpd14)

# Check model conditions
hist(resid(mod_glucose14_faithpd14))
plot(mod_glucose14_faithpd14)
car::qqPlot(mod_glucose14_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - faith's pd day 21#####
mod_glucose21_faithpd21 <- lme(fixed = d21glucose ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_glucose21_faithpd21)
anova(mod_glucose21_faithpd21)
tab_model(mod_glucose21_faithpd21)

# Check model conditions
hist(resid(mod_glucose21_faithpd21))
plot(mod_glucose21_faithpd21)
car::qqPlot(mod_glucose21_faithpd21, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 7 - Firmicutes day 7#####
mod_glucose7_firm7 <- lme(fixed = d7glucose ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose7_firm7)
anova(mod_glucose7_firm7)
tab_model(mod_glucose7_firm7)

# Check model conditions
hist(resid(mod_glucose7_firm7))
plot(mod_glucose7_firm7)
car::qqPlot(mod_glucose7_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - Firmicutes day 14#####
mod_glucose14_firm14 <- lme(fixed = d14glucose ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose14_firm14)
anova(mod_glucose14_firm14)
tab_model(mod_glucose14_firm14)

# Check model conditions
hist(resid(mod_glucose14_firm14))
plot(mod_glucose14_firm14)
car::qqPlot(mod_glucose14_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - Firmicutes day 21#####
mod_glucose21_firm21 <- lme(fixed = d21glucose ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_glucose21_firm21)
anova(mod_glucose21_firm21)
tab_model(mod_glucose21_firm21)

# Check model conditions
hist(resid(mod_glucose21_firm21))
plot(mod_glucose21_firm21)
car::qqPlot(mod_glucose21_firm21, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 7 - Proteobacteria day 7#####
mod_glucose7_prot7 <- lme(fixed = d7glucose ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose7_prot7)
anova(mod_glucose7_prot7)
tab_model(mod_glucose7_prot7)

# Check model conditions
hist(resid(mod_glucose7_prot7))
plot(mod_glucose7_prot7)
car::qqPlot(mod_glucose7_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - Proteobacteria day 14#####
mod_glucose14_prot14 <- lme(fixed = d14glucose ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose14_prot14)
anova(mod_glucose14_prot14)
tab_model(mod_glucose14_prot14)

# Check model conditions
hist(resid(mod_glucose14_prot14))
plot(mod_glucose14_prot14)
car::qqPlot(mod_glucose14_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - Proteobacteria day 21#####
mod_glucose21_prot21 <- lme(fixed = d21glucose ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_glucose21_prot21)
anova(mod_glucose21_prot21)
tab_model(mod_glucose21_prot21)

# Check model conditions
hist(resid(mod_glucose21_prot21))
plot(mod_glucose21_prot21)
car::qqPlot(mod_glucose21_prot21, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 7 - shannon day 7#####
mod_hematocrit7_shannon7 <- lme(fixed = d7hct ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit7_shannon7)
anova(mod_hematocrit7_shannon7)
tab_model(mod_hematocrit7_shannon7)

# Check model conditions
hist(resid(mod_hematocrit7_shannon7))
plot(mod_hematocrit7_shannon7)
car::qqPlot(mod_hematocrit7_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - shannon day 14#####
mod_hematocrit14_shannon14 <- lme(fixed = d14hct ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit14_shannon14)
anova(mod_hematocrit14_shannon14)
tab_model(mod_hematocrit14_shannon14)

# Check model conditions
hist(resid(mod_hematocrit14_shannon14))
plot(mod_hematocrit14_shannon14)
car::qqPlot(mod_hematocrit14_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - shannon day 21#####
mod_hematocrit21_shannon21 <- lme(fixed = d21hct ~ shannon, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_hematocrit21_shannon21)
anova(mod_hematocrit21_shannon21)
tab_model(mod_hematocrit21_shannon21)

# Check model conditions
hist(resid(mod_hematocrit21_shannon21))
plot(mod_hematocrit21_shannon21)
car::qqPlot(mod_hematocrit21_shannon21, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 7 - chao1 day 7#####
mod_hematocrit7_chao7 <- lme(fixed = d7hct ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit7_chao7)
anova(mod_hematocrit7_chao7)
tab_model(mod_hematocrit7_chao7)

# Check model conditions
hist(resid(mod_hematocrit7_chao7))
plot(mod_hematocrit7_chao7)
car::qqPlot(mod_hematocrit7_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - chao1 day 14#####
mod_hematocrit14_chao14 <- lme(fixed = d14hct ~ logchao + year, random=~1|nest_year/, na.action=na.omit, data=amke14)
summary(mod_hematocrit14_chao14)
anova(mod_hematocrit14_chao14)
tab_model(mod_hematocrit14_chao14)

# Check model conditions
hist(resid(mod_hematocrit14_chao14))
plot(mod_hematocrit14_chao14)
car::qqPlot(mod_hematocrit14_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - chao1 day 21#####
mod_hematocrit21_chao21 <- lme(fixed = d21hct ~ logchao + year, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_hematocrit21_chao21)
anova(mod_hematocrit21_chao21)
tab_model(mod_hematocrit21_chao21)

# Check model conditions
hist(resid(mod_hematocrit21_chao21))
plot(mod_hematocrit21_chao21)
car::qqPlot(mod_hematocrit21_chao21, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 7 - faith's pd day 7#####
mod_hematocrit7_faithpd7 <- lme(fixed = d7hct ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit7_faithpd7)
anova(mod_hematocrit7_faithpd7)
tab_model(mod_hematocrit7_faithpd7)

# Check model conditions
hist(resid(mod_hematocrit7_faithpd7))
plot(mod_hematocrit7_faithpd7)
car::qqPlot(mod_hematocrit7_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - faith's pd day 14#####
mod_hematocrit14_faithpd14 <- lme(fixed = d14hct ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit14_faithpd14)
anova(mod_hematocrit14_faithpd14)
tab_model(mod_hematocrit14_faithpd14)

# Check model conditions
hist(resid(mod_hematocrit14_faithpd14))
plot(mod_hematocrit14_faithpd14)
car::qqPlot(mod_hematocrit14_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - faith's pd day 21#####
mod_hematocrit21_faithpd21 <- lme(fixed = d21hct ~ logfaith_pd, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_hematocrit21_faithpd21)
anova(mod_hematocrit21_faithpd21)
tab_model(mod_hematocrit21_faithpd21)

# Check model conditions
hist(resid(mod_hematocrit21_faithpd21))
plot(mod_hematocrit21_faithpd21)
car::qqPlot(mod_hematocrit21_faithpd21, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 7 - Firmicutes day 7#####
mod_hematocrit7_firm7 <- lme(fixed = d7hct ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit7_firm7)
anova(mod_hematocrit7_firm7)
tab_model(mod_hematocrit7_firm7)

# Check model conditions
hist(resid(mod_hematocrit7_firm7))
plot(mod_hematocrit7_firm7)
car::qqPlot(mod_hematocrit7_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - Firmicutes day 14#####
mod_hematocrit14_firm14 <- lme(fixed = d14hct ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit14_firm14)
anova(mod_hematocrit14_firm14)
tab_model(mod_hematocrit14_firm14)

# Check model conditions
hist(resid(mod_hematocrit14_firm14))
plot(mod_hematocrit14_firm14)
car::qqPlot(mod_hematocrit14_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - Firmicutes day 21#####
mod_hematocrit21_firm21 <- lme(fixed = d21hct ~ Firmicutes, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_hematocrit21_firm21)
anova(mod_hematocrit21_firm21)
tab_model(mod_hematocrit21_firm21)

# Check model conditions
hist(resid(mod_hematocrit21_firm21))
plot(mod_hematocrit21_firm21)
car::qqPlot(mod_hematocrit21_firm21, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 7 - Proteobacteria day 7#####
mod_hematocrit7_prot7 <- lme(fixed = d7hct ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit7_prot7)
anova(mod_hematocrit7_prot7)
tab_model(mod_hematocrit7_prot7)

# Check model conditions
hist(resid(mod_hematocrit7_prot7))
plot(mod_hematocrit7_prot7)
car::qqPlot(mod_hematocrit7_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - Proteobacteria day 14#####
mod_hematocrit14_prot14 <- lme(fixed = d14hct ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit14_prot14)
anova(mod_hematocrit14_prot14)
tab_model(mod_hematocrit14_prot14)

# Check model conditions
hist(resid(mod_hematocrit14_prot14))
plot(mod_hematocrit14_prot14)
car::qqPlot(mod_hematocrit14_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - Proteobacteria day 21#####
mod_hematocrit21_prot21 <- lme(fixed = d21hct ~ Proteobacteria, random=~1|nest_year, na.action=na.omit, data=amke21)
summary(mod_hematocrit21_prot21)
anova(mod_hematocrit21_prot21)
tab_model(mod_hematocrit21_prot21)

# Check model conditions
hist(resid(mod_hematocrit21_prot21))
plot(mod_hematocrit21_prot21)
car::qqPlot(mod_hematocrit21_prot21, 
            simulate = FALSE,
            id = FALSE)

##### Nestling physiology - time-lagged comparisons #####

##### Glucose day 14 - shannon day 7 #####
mod_glucose14_shannon7 <- lme(fixed = d14glucose ~ shannon + d7glucose, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose14_shannon7)
anova(mod_glucose14_shannon7)
tab_model(mod_glucose14_shannon7)

# Check model conditions
hist(resid(mod_glucose14_shannon7))
plot(mod_glucose14_shannon7)
car::qqPlot(mod_glucose14_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - shannon day 14 #####
mod_glucose21_shannon14 <- lme(fixed = d21glucose ~ shannon + d14glucose, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose21_shannon14)
anova(mod_glucose21_shannon14)
tab_model(mod_glucose21_shannon14)

# Check model conditions
hist(resid(mod_glucose21_shannon14))
plot(mod_glucose21_shannon14)
car::qqPlot(mod_glucose21_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - chao1 day 7 #####
mod_glucose14_chao7 <- lme(fixed = d14glucose ~ logchao + d7glucose + year, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose14_chao7)
anova(mod_glucose14_chao7)
tab_model(mod_glucose14_chao7)

# Check model conditions
hist(resid(mod_glucose14_chao7))
plot(mod_glucose14_chao7)
car::qqPlot(mod_glucose14_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - chao1 day 14 #####
mod_glucose21_chao14 <- lme(fixed = d21glucose ~ logchao+ d14glucose + year, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose21_chao14)
anova(mod_glucose21_chao14)
tab_model(mod_glucose21_chao14)

# Check model conditions
hist(resid(mod_glucose21_chao14))
plot(mod_glucose21_chao14)
car::qqPlot(mod_glucose21_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - faith's pd day 7 #####
mod_glucose14_faithpd7 <- lme(fixed = d14glucose ~ logfaith_pd + d7glucose, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose14_faithpd7)
anova(mod_glucose14_faithpd7)
tab_model(mod_glucose14_faithpd7)

# Check model conditions
hist(resid(mod_glucose14_faithpd7))
plot(mod_glucose14_faithpd7)
car::qqPlot(mod_glucose14_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - faith's pd day 14 #####
mod_glucose21_faithpd14 <- lme(fixed = d21glucose ~ logfaith_pd + d14glucose, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose21_faithpd14)
anova(mod_glucose21_faithpd14)
tab_model(mod_glucose21_faithpd14)

# Check model conditions
hist(resid(mod_glucose21_faithpd14))
plot(mod_glucose21_faithpd14)
car::qqPlot(mod_glucose21_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - Firmicutes day 7 #####
mod_glucose14_firm7 <- lme(fixed = d14glucose ~ Firmicutes + d7glucose, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose14_firm7)
anova(mod_glucose14_firm7)
tab_model(mod_glucose14_firm7)

# Check model conditions
hist(resid(mod_glucose14_firm7))
plot(mod_glucose14_firm7)
car::qqPlot(mod_glucose14_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - Firmicutes day 14 #####
mod_glucose21_firm14 <- lme(fixed = d21glucose ~ Firmicutes + d14glucose, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose21_firm14)
anova(mod_glucose21_firm14)
tab_model(mod_glucose21_firm14)

# Check model conditions
hist(resid(mod_glucose21_firm14))
plot(mod_glucose21_firm14)
car::qqPlot(mod_glucose21_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 14 - Proteobacteria day 7 #####
mod_glucose14_prot7 <- lme(fixed = d14glucose ~ Proteobacteria + d7glucose, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_glucose14_prot7)
anova(mod_glucose14_prot7)
tab_model(mod_glucose14_prot7)

# Check model conditions
hist(resid(mod_glucose14_prot7))
plot(mod_glucose14_prot7)
car::qqPlot(mod_glucose14_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Glucose day 21 - Proteobacteria day 14 #####
mod_glucose21_prot14 <- lme(fixed = d21glucose ~ Proteobacteria + d14glucose, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_glucose21_prot14)
anova(mod_glucose21_prot14)
tab_model(mod_glucose21_prot14)

# Check model conditions
hist(resid(mod_glucose21_prot14))
plot(mod_glucose21_prot14)
car::qqPlot(mod_glucose21_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - shannon day 7 #####
mod_hematocrit14_shannon7 <- lme(fixed = d14hct ~ shannon + d7hct, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit14_shannon7)
anova(mod_hematocrit14_shannon7)
tab_model(mod_hematocrit14_shannon7)

# Check model conditions
hist(resid(mod_hematocrit14_shannon7))
plot(mod_hematocrit14_shannon7)
car::qqPlot(mod_hematocrit14_shannon7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - shannon day 14 #####
mod_hematocrit21_shannon14 <- lme(fixed = d21hct ~ shannon + d14hct, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit21_shannon14)
anova(mod_hematocrit21_shannon14)
tab_model(mod_hematocrit21_shannon14)

# Check model conditions
hist(resid(mod_hematocrit21_shannon14))
plot(mod_hematocrit21_shannon14)
car::qqPlot(mod_hematocrit21_shannon14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - chao1 day 7 #####
mod_hematocrit14_chao7 <- lme(fixed = d14hct ~ logchao + d7hct + year, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit14_chao7)
anova(mod_hematocrit14_chao7)
tab_model(mod_hematocrit14_chao7)

# Check model conditions
hist(resid(mod_hematocrit14_chao7))
plot(mod_hematocrit14_chao7)
car::qqPlot(mod_hematocrit14_chao7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - chao1 day 14 #####
mod_hematocrit21_chao14 <- lme(fixed = d21hct ~ logchao+ d14hct + year, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit21_chao14)
anova(mod_hematocrit21_chao14)
tab_model(mod_hematocrit21_chao14)

# Check model conditions
hist(resid(mod_hematocrit21_chao14))
plot(mod_hematocrit21_chao14)
car::qqPlot(mod_hematocrit21_chao14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - faith's pd day 7 #####
mod_hematocrit14_faithpd7 <- lme(fixed = d14hct ~ logfaith_pd + d7hct, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit14_faithpd7)
anova(mod_hematocrit14_faithpd7)
tab_model(mod_hematocrit14_faithpd7)

# Check model conditions
hist(resid(mod_hematocrit14_faithpd7))
plot(mod_hematocrit14_faithpd7)
car::qqPlot(mod_hematocrit14_faithpd7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - faith's pd day 14 #####
mod_hematocrit21_faithpd14 <- lme(fixed = d21hct ~ logfaith_pd + d14hct, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit21_faithpd14)
anova(mod_hematocrit21_faithpd14)
tab_model(mod_hematocrit21_faithpd14)

# Check model conditions
hist(resid(mod_hematocrit21_faithpd14))
plot(mod_hematocrit21_faithpd14)
car::qqPlot(mod_hematocrit21_faithpd14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - Firmicutes day 7 #####
mod_hematocrit14_firm7 <- lme(fixed = d14hct ~ Firmicutes + d7hct, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit14_firm7)
anova(mod_hematocrit14_firm7)
tab_model(mod_hematocrit14_firm7)

# Check model conditions
hist(resid(mod_hematocrit14_firm7))
plot(mod_hematocrit14_firm7)
car::qqPlot(mod_hematocrit14_firm7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - Firmicutes day 14 #####
mod_hematocrit21_firm14 <- lme(fixed = d21hct ~ Firmicutes + d14hct, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit21_firm14)
anova(mod_hematocrit21_firm14)
tab_model(mod_hematocrit21_firm14)

# Check model conditions
hist(resid(mod_hematocrit21_firm14))
plot(mod_hematocrit21_firm14)
car::qqPlot(mod_hematocrit21_firm14, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 14 - Proteobacteria day 7 #####
mod_hematocrit14_prot7 <- lme(fixed = d14hct ~ Proteobacteria + d7hct, random=~1|nest_year, na.action=na.omit, data=amke7)
summary(mod_hematocrit14_prot7)
anova(mod_hematocrit14_prot7)
tab_model(mod_hematocrit14_prot7)

# Check model conditions
hist(resid(mod_hematocrit14_prot7))
plot(mod_hematocrit14_prot7)
car::qqPlot(mod_hematocrit14_prot7, 
            simulate = FALSE,
            id = FALSE)

##### Hematocrit day 21 - Proteobacteria day 14 #####
mod_hematocrit21_prot14 <- lme(fixed = d21hct ~ Proteobacteria + d14hct, random=~1|nest_year, na.action=na.omit, data=amke14)
summary(mod_hematocrit21_prot14)
anova(mod_hematocrit21_prot14)
tab_model(mod_hematocrit21_prot14)

# Check model conditions
hist(resid(mod_hematocrit21_prot14))
plot(mod_hematocrit21_prot14)
car::qqPlot(mod_hematocrit21_prot14, 
            simulate = FALSE,
            id = FALSE)

##### Figures - Alpha diversity components #####

##### FIGURE 1 - FINAL VERSION IN MANUSCRIPT #####

# Figure 1a Year log Chao1 box plot

fig1a <- ggplot(AMKE, aes(x=year, y=logchao, color=year)) + 
  geom_boxplot() + 
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  xlab('Sampling Year') + 
  ylab('Log Chao1 Index') +
  scale_color_discrete(name="Sampling Year") +
  annotate(geom="text", x=2, y=8, label="(d)",size=4,family="sans")

ggsave("figure1a_year_chao1.pdf", height=4, width=5, device="pdf") # save a PDF 3 inches by 4 inches

# Figure 1c age log Chao1 box plot

#reorder age values

AMKE$age <- factor(AMKE$age, levels=c(7, 14, 21))

fig1c <- ggplot(AMKE, aes(x=age, y=logchao, color=age)) + 
  geom_boxplot() + 
  theme_bw() +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  xlab('Age (Days)') + 
  ylab('Log Chao1 Index') +
  scale_color_discrete(limits=c("7", "14", "21"), name="Age (Days)") +
  annotate(geom="text", x=3, y=8, label="(c)",size=4,family="sans")

ggsave("figure1c_age_chao1.pdf", height=4, width=5, device="pdf")

##### FIGURE 2 - FINAL VERSION IN MANUSCRIPT #####

#make in ggplot2, remove 2018 data so nest IDs do not show in legend
amke21y19<-subset(amke21, year == "2019")
table(amke21y19$year)

fig2 <- ggplot(data=amke21y19, aes(x=Hmaxmass, y=shannon, color=nest)) +
  geom_point() +
  theme_bw() +
  geom_smooth(method=lm, colour="black") +
  labs(x="Diet diversity (Shannon Index)", 
       y="Microbial diversity \n (Shannon Index) at day 21") +
  scale_color_discrete(name="Nest ID") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x= 0.55, y=7.3, label="",size=4,family="sans")

ggsave("figure2_diet_diversity_shannon.pdf", height=4, width=5, device="pdf") 

##### FIGURE 3 - FINAL VERSION IN MANUSCRIPT #####

amke7$Sex<-amke7$sex
amke14$Sex<-amke14$sex
amke21$Sex<-amke21$sex

# A: Contemporary log Faith's PD day 14 to mass day 14

fig3a <- ggplot(data=amke14, aes(x=logfaith_pd, y=d14mass, color=year)) +
  geom_point(aes(shape=Sex)) +
  theme_bw() + 
  theme(legend.justification=c(0.97,0.9), legend.position=c(0.97,0.9)) +
  geom_smooth(aes(group=year), method='lm', formula= y~x) +
  labs(x="Microbial diversity \n(Log Faith's PD) at day 14", y="Mass (g) at day 14") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x=3.5, y=140, label="",size=4,family="sans") +
  guides(color = "none")  

ggsave("figure3a_mass_faithpd_contemp.pdf", height=4, width=5, device="pdf")

# B: Time-lagged log Faith's PD day 7 to mass day 14

fig3b <- ggplot(data=amke7, aes(x=logfaith_pd, y=d14mass, color=year)) +
  geom_point(aes(shape=Sex)) +
  theme_bw() + 
  theme(legend.justification=c(0.97,0.9), legend.position=c(0.97,0.9)) +
  geom_smooth(aes(group=year), method='lm', formula= y~x) +
  labs(x="Microbial diversity \n(Log Faith's PD) at day 7", y="Mass (g) at day 14") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x=3.5, y=140, label="",size=4,family="sans") +
  guides(color = "none")  

ggsave("figure3b_mass_faithpd_lagged.pdf", height=4, width=5, device="pdf")

# C: Time-lagged log Chao1 day 7 to mass day 14

fig3c <- ggplot(data=amke7, aes(x=logchao, y=d14mass, color=year)) +
  geom_point(aes(shape=Sex)) +
  theme_bw() + 
  theme(legend.justification=c(0.97,0.9), legend.position=c(0.97,0.9)) +
  geom_smooth(aes(group=year), method='lm', formula= y~x) +
  labs(x="Microbial diversity \n(Log Chao1 Index) at day 7", y="Mass (g) at day 14") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x=7.0, y=145, label="",size=4,family="sans") +
  guides(color = "none")  

ggsave("figure3c_mass_chao1.pdf", height=4, width=5, device="pdf")

# D: Time-lagged Shannon day 14 to mass day 21

fig3d <- ggplot(data=amke14, aes(x=Firmicutes, y=d21mass, color=year)) +
  geom_point(aes(shape=Sex)) +
  theme_bw() + 
  theme(legend.justification=c(0.97,0.9), legend.position=c(0.97,0.9)) +
  geom_smooth(aes(group=year), method='lm', formula= y~x) +
  labs(x="Microbial diversity \n(Shannon Index) at day 14", y="Mass (g) at day 21") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x=7.5, y=145, label="",size=4,family="sans") +
  guides(color = "none")  

ggsave("figure3d_mass_shannon.pdf", height=4, width=5, device="pdf")

##### FIGURE 4 - FINAL VERSION IN MANUSCRIPT #####

amke7$Sex<-amke7$sex

fig4 <- ggplot(data=amke7, aes(x=shannon, y=d14glucose, color=year)) +
  geom_point(aes(shape=Sex)) +
  theme_bw() + 
  theme(legend.justification=c(0.97,0.9), legend.position=c(0.97,0.9)) +
  geom_smooth(aes(group=year), method='lm', formula= y~x) +
  labs(x="Microbial diversity \n(Shannon Index) at day 7", y="Glucose (mg/dL) at day 14") +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  annotate(geom="text", x=7.5, y=145, label="",size=4,family="sans") +
  guides(color = "none")  

ggsave("figure4_glucose_shannon.pdf", height=4, width=5, device="pdf")
