###### Disentangling relationships between physiology, morphology, diet, and gut microbial diversity in American Kestrel nestlings ######
# Written by: Jennifer L. Houtz
# Manuscript ID: JAV12893
# Beta Diversity Statistical Analysis and Figures R script

# This code is used to conduct statistical analyses on beta diversity metrics (Bray-Curtis and Jaccard)

#####Data Preparation#####

# Load packages

pacman::p_load("tidyverse", "ggplot2", "phyloseq",
               "vegan", "devtools", "sjPlot", "here", "biomformat", "permute")

# Read in metadata

metadata<-read.csv("kestrel_micro_metadata.csv")
str(metadata)

# Change variable types

metadata$age <- as.factor(metadata$age)
metadata$sex <- as.factor(metadata$sex)
metadata$year <- as.factor(metadata$year)

# Read in distance matrices that were calculated in QIIME2

# Bray-Curtis (exported from QIIME2)

braycurtis_distance_matrix <- read.csv("braycurtis_distance_matrix.csv")

# Jaccard (exported from QIIME2)

jaccard_distance_matrix <- read.csv("jaccard_distance_matrix.csv")

# Set up Jaccard matrix

class(jaccard_distance_matrix)
head(jaccard_distance_matrix)

jaccard_meta_distance <- inner_join(jaccard_distance_matrix, metadata, by="SampleID")

jaccard_all_dist <- jaccard_meta_distance %>%
  select(all_of(.[["SampleID"]])) %>%
  as.dist()

# Set up Bray Curtis matrix

braycurtis_distance_matrix

braycurtis_meta_distance <- inner_join(braycurtis_distance_matrix, metadata, by="SampleID")

braycurtis_all_dist <- braycurtis_meta_distance %>%
  select(all_of(.[["SampleID"]])) %>%
  as.dist()

# Upload ASV table with genus level taxonomy and metadata columns (exported csv from level 6 taxa bar plot made in QIIME2)

ASV_table_genus_taxonomy <- read.csv("genus_level_taxonomy.csv")

# Prior to adonis, need to make sure nested random effects are balanced (# samples per chick within nest)

all_data <- ASV_table_genus_taxonomy

cbind(row.names(all_data), all_data$index)

names(all_data)

metadata %>%
  group_by(nest, chick_ID) %>%
  summarize(n()) %>%
  View()

with(metadata, table(chick_ID, age))

# Must subsample plots to be balanced, but do this 1000 times because of random sampling

with(all_data, table(chick_ID))

all_data = all_data %>% dplyr::filter(!chick_ID %in% c("314-1", "707-4"))

all_data$chick_ID

minrep=min(with(all_data, table(chick_ID)))

minrep

i = 1
numreps=1000 

adonisresults <- array(NA, dim=c(4,5,numreps))

##### PERMANOVAs for age, sex, and sampling year #####

##### Bray Curtis - age, sex, and sampling year #####

# Age*sex interaction + year

for (i in 1:numreps) {
  all_data_sub <- all_data %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
               blocks = nest, nperm = 1000))
  
  permresult_bray_age_sexint <- adonis2(ASV_sub ~ age*sex + year, data=metadata_sub, distance="bray", permutations=hsub, by = "margin")
  adonisresults[,,i] <- as.matrix(permresult_bray_age_sexint$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_bray_age_sexint

# Age. sex, and year as separate terms

for (i in 1:numreps) {
  all_data_sub <- all_data %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_bray_age_sex <- adonis2(ASV_sub ~ age + sex + year, data=metadata_sub, distance="bray", permutations=hsub, by = "margin")
  adonisresults[,,i] <- as.matrix(permresult_bray_age_sex$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_bray_age_sex

# Checking group dispersions with betadisper analysis

# Age

dist_matrix_bray <- vegdist(ASV_sub, method="bray")
beta_disp_bray_age <-betadisper(dist_matrix_bray, metadata_sub$age)
set.seed(25)
permutest(beta_disp_bray_age, permutations = 9999)

# Sex

beta_disp_bray_sex <-betadisper(dist_matrix_bray, metadata_sub$sex)
set.seed(25)
permutest(beta_disp_bray_sex, permutations = 9999)

# Year

beta_disp_bray_year <-betadisper(dist_matrix_bray,metadata_sub$year)
set.seed(25)
permutest(beta_disp_bray_year, permutations = 9999)

##### Jaccard #####

# Age*sex interaction + year

for (i in 1:numreps) {
  all_data_sub <- all_data %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_jaccard_age_sexint <- adonis2(ASV_sub ~ age*sex + year, data=metadata_sub, distance="jaccard", permutations=hsub, by = "margin")
  adonisresults[,,i] <- as.matrix(permresult_jaccard_age_sexint$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_jaccard_age_sexint

# Age. sex, and year as separate terms

for (i in 1:numreps) {
  all_data_sub <- all_data %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_jaccard_age_sex <- adonis2(ASV_sub ~ age + sex + year, data=metadata_sub, distance="jaccard", permutations=hsub, by = "margin")
  adonisresults[,,i] <- as.matrix(permresult_jaccard_age_sex$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_jaccard_age_sex

# Checking group dispersions with betadisper analysis

# Age

dist_matrix_jaccard <- vegdist(ASV_sub, method="jaccard")
beta_disp_jaccard_age <-betadisper(dist_matrix_jaccard, metadata_sub$age)
set.seed(25)
permutest(beta_disp_jaccard_age, permutations = 9999)

# Sex

beta_disp_jaccard_sex <-betadisper(dist_matrix_jaccard, metadata_sub$sex)
set.seed(25)
permutest(beta_disp_jaccard_sex, permutations = 9999)

# Year

beta_disp_jaccard_year <-betadisper(dist_matrix_jaccard, metadata_sub$year)
set.seed(25)
permutest(beta_disp_jaccard_year, permutations = 9999)

##### Pairwise PERMANOVAs for age #####

##### d7 vs d14 #####
all_data714 <- all_data %>% filter(age!= "21") %>%
  group_by(chick_ID) %>%
  mutate(age714=n()) %>%
  filter(age714==2)

##### Bray Curtis #####

for (i in 1:numreps) {
  all_data_sub <- all_data714 %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_bray_age7vs14 <- adonis2(ASV_sub ~ age, data=metadata_sub, distance="bray", permutations=hsub)
  adonisresults[,,i] <- as.matrix(permresult_bray_age7vs14$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_bray_age7vs14

##### Jaccard #####

for (i in 1:numreps) {
  all_data_sub <- all_data714 %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_jaccard_age7vs14 <- adonis2(ASV_sub ~ age, data=metadata_sub, distance="jaccard", permutations=hsub)
  adonisresults[,,i] <- as.matrix(permresult_jaccard_age7vs14$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_jaccard_age7vs14

##### d14 vs d21 #####
all_data1421 <- all_data %>% filter(age!= "7") %>%
  group_by(chick_ID) %>%
  mutate(age1421=n()) %>%
  filter(age1421==2)

##### Bray Curtis #####

for (i in 1:numreps) {
  all_data_sub <- all_data1421 %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_bray_age14vs21 <- adonis2(ASV_sub ~ age, data=metadata_sub, distance="bray", permutations=hsub)
  adonisresults[,,i] <- as.matrix(permresult_bray_age14vs21$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_bray_age14vs21

##### Jaccard #####

for (i in 1:numreps) {
  all_data_sub <- all_data1421 %>% group_by(nest, chick_ID) %>% slice_sample(n=minrep) %>% arrange(nest, chick_ID, age)
  
  ASV_sub <- all_data_sub %>% ungroup%>%select(-index:-year)
  
  metadata_sub <- all_data_sub %>% ungroup%>%select(index:year)
  
  hsub <- with(metadata_sub, how(within=Within(type="free"),plots=Plots(strata=chick_ID, type="free"),
                                 blocks = nest, nperm = 1000))
  
  permresult_jaccard_age14vs21 <- adonis2(ASV_sub ~ age, data=metadata_sub, distance="jaccard", permutations=hsub)
  adonisresults[,,i] <- as.matrix(permresult_jaccard_age14vs21$aov.tab)
  rm(all_data_sub, metadata_sub, ASV_sub)
  
}

permresult_jaccard_age14vs21

##### Mantel test #####

# Calculate Jaccard distance for diet on day 21 samples only 

diet_frequency <- as.data.frame(read.csv("diet_frequency_data.csv"))

metadata

# Make sure the samples are the rownames

diet_frequency <- diet_frequency %>% remove_rownames %>% column_to_rownames(var="sample_name")

# Calculate jaccard distance for nest level diet beta diversity

diet_day21_jaccard_matrix <- vegdist(diet_frequency, method = "jaccard")

# Upload jaccard day 21 only 2019 only microbiome matrix (exported from QIIME2)

jaccard_day21_micro_distance_matrix <- read.csv("jaccard_day21only_2019only_distance_matrix.csv")

jaccard_day21_micro_distance_matrix <- jaccard_day21_micro_distance_matrix %>%
  select(all_of(.[["SampleID"]])) %>%
  as.dist()

# Upload bray curtis day 21 only 2019 only microbiome matrix (exported from QIIME2)

braycurtis_day21_micro_distance_matrix <- read.csv("braycurtis_day21only_2019only_distance_matrix.csv")

braycurtis_day21_micro_distance_matrix <- braycurtis_day21_micro_distance_matrix %>%
  select(all_of(.[["SampleID"]])) %>%
  as.dist()

# Mantel test jaccard micro day 21 vs jaccard diet day 21

mantel(jaccard_day21_micro_distance_matrix, diet_day21_jaccard_matrix, method = "pearson", permutations=1000)

# Mantel test bray curtis micro day 21 vs jaccard diet day 21

mantel(braycurtis_day21_micro_distance_matrix, diet_day21_jaccard_matrix, method = "pearson", permutations=1000)

##### PERMANOVA for diet prey types #####

# Use Bray-Curtis and Jaccard of day 21 samples only 

# Bray Curtis

str(diet_frequency)

diet_frequency$nest <- as.factor(diet_frequency$nest)

minrep_diet=min(with(diet_frequency, table(nest)))

diet_frequency = diet_frequency %>% dplyr::filter(!nest %in% c("630"))

prey_type_braycurtis_permresult <- adonis2(braycurtis_day21_micro_distance_matrix ~ mammals + passerines + arthropods + annelid, 
                                        data=diet_frequency, permutations=1000, by = "margin", strata = nest)

# Jaccard

prey_type_jaccard_permresult <- adonis2(jaccard_day21_micro_distance_matrix ~ mammals + passerines + arthropods + annelid, 
                                     data=diet_frequency, permutations=1000, by = "margin", strata = nest)
  
##### Kendall rank correlations with diet prey types #####

ASV_day21 <- subset(ASV_table_genus_taxonomy, age == 21)

ASV_diet_cor <- diet_frequency %>% 
  add_rownames(var = "index") %>%
  left_join(ASV_table_genus_taxonomy, by = "index")

ASV_genera <- names(ASV_table_genus_taxonomy) [c(5, 6, 7, 8, 9, 10, 11, 14, 15, 16, 17)]
diet_type <- names(diet_frequency) [1:4]
results_table <- expand.grid(ASV=ASV_genera, diet=diet_type)

results_table$cor <- NA

results_table$p <- NA
i = ASV_genera[1]
j = diet_type [1]

for (i in ASV_genera) {
  for (j in diet_type) {
    results <- cor.test(ASV_diet_cor[[i]], ASV_diet_cor[[j]], method = "kendall")
    results_table[results_table$ASV==i&results_table$diet==j,"cor"] = results$estimate
    results_table[results_table$ASV==i&results_table$diet==j,"p"] = results$p.value
    jpeg(filename = paste(i,j,".jpeg"))
    plot(ASV_diet_cor[[i]], ASV_diet_cor[[j]], xlab = i, ylab = j)
    dev.off()
  }
}

results_table$padj <- p.adjust(results_table$p, method = "BH")

cor(ASV_table_genus_taxonomy$"d__Bacteria;p__Firmicutes;c__Bacilli;o__Lactobacillales;f__Enterococcaceae;g__Enterococcus",diet_frequency$mammals, method = "pearson")

pearson_result <- cor.test(data$Girth, data$Height, method = 'pearson')

write.csv(results_table,"diet_ASV_kendall_correlations.csv", row.names = TRUE)

##### SIMPER Bubble Chart Figure S4 - FINAL VERSION IN SUPPORTING MATERIAL ####

# Load in genus level SIMPER results from PAST (v 4.11) as a csv 

simper_results <- read.csv("SIMPER_genus_age.csv") # Table S12 in SSupporting Information

simper_results$age_comparison <- factor(simper_results$age_comparison, levels=c("7 vs 14", "14 vs 21"))

# Create bubble chart with % contribution
simper_fig <- ggplot(simper_results, aes(x = age_comparison, y = bacterial_genus,
                      size = percent_contribution,
                      color = Phylum))+
  geom_point(alpha = 0.7)+
  scale_size(range = c(0.1, 10), name = "% Contribution to Dissimilarity")+
  labs(x="Age Comparison (Days)", y="Bacterial Genus") +
  theme(plot.title = element_text(hjust = 0.5))+
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme_bw()
  

ggsave("simper_bubble_figure.pdf", height=6, width=6, device="pdf")

##### Figure 1 - Beta diversity components - FINAL VERSION IN MANUSCRIPT #####

# Upload Jaccard PCoA (exported from QIIME2)

jaccard_pcoa <- read.csv("jaccard_kestrel_pcoa_results.csv")

# Figure 1b Jaccard year PCoA

fig1b <- jaccard_pcoa$data$Vectors %>%
  select(SampleID, PC1, PC2) %>%
  left_join(metadata) %>%
  ggplot(aes(x=PC1, y=PC2, color=`year`)) +
  geom_point(alpha=0.5) + #alpha controls transparency and helps when points are overlapping
  theme_bw() +
  scale_color_discrete(name="Sampling Year") +
  annotate(geom="text", x=3, y=130, label="(b)",size=4,family="sans")
ggsave("figure1b_PCoA_Jaccard_year.pdf", height=4, width=5, device="pdf")

# Figure 1d Jaccard age PCoA

fig1d <- jaccard_pcoa$data$Vectors %>%
  select(SampleID, PC1, PC2) %>%
  left_join(metadata) %>%
  ggplot(aes(x=PC1, y=PC2, color=`age`)) +
  geom_point(alpha=0.5) + #alpha controls transparency and helps when points are overlapping
  theme_bw() +
  scale_color_discrete(limits=c("7", "14", "21"), name="Age (Days)") +
  annotate(geom="text", x=3, y=130, label="(a)",size=4,family="sans")

ggsave("figure1d_PCoA_Jaccard_age.pdf", height=4, width=5, device="pdf")

