###### Disentangling relationships between physiology, morphology, diet, and gut microbial diversity in American Kestrel nestlings ######
# Written by: Jennifer L. Houtz
# Manuscript ID: JAV12893
# Decontam R script

# This code is used to remove contaminants from the ASV table after the initial filtering in QIIME2
# We indicate where data objects are imported and exported to QIIME2

# Load packages

pacman::p_load("tidyverse", "decontam", "phyloseq", "devtools", "biomformat")

# Read in the QIIME2 objects after 

# Upload ASV, taxonomy, tree and metadata files to phyloseq

# ASV table (exported from QIIME2)
unrarefied_ASV_table <- read.csv ("unrarefied_ASV_table.csv", row.names=1) #read in ASV table with feature names as rownames
str (unrarefied_ASV_table)
head (unrarefied_ASV_table)
unrarefied_ASV_table <- as.matrix (unrarefied_ASV_table) #make into a matrix

# Taxonomy file (exported from QIIME2)
taxonomy <- read.csv ("taxonomy.csv", row.names=1)
taxonomy <- separate(taxonomy, Taxon, c("Kingdom","Phylum","Class","Order","Family","Genus","Species"), sep="; ")
str (taxonomy)
taxonomy <- as.matrix (taxonomy)

# Read in phylogenetic tree as a phyloseq object (exported from QIIME2)
phy_tree <- read_tree ("tree.nwk")

# Load metadata file
metadatafull <- read.csv("kestrel_micro_metadata.csv")
str(metadatafull)  
row.names(metadatafull)<-metadatafull$SampleID

# Import all as phyloseq objects
ASV <- otu_table(unrarefied_ASV_table, taxa_are_rows = TRUE)
TAX <- tax_table(taxonomy)
META <- sample_data(metadatafull)
head(META)

# Check that the ASV and sample names are consistent across objects
str(taxa_names(TAX))
str(taxa_names(ASV))
str(taxa_names(phy_tree))

str(sample_names(ASV))
str(sample_names(META))

#### Merge into phyloseq object ####
physeq <- phyloseq(ASV, TAX, META, phy_tree)
physeq 

# Use decontam package to remove contaminants based on negative kit controls
# Remove contaminants with the combined function of prevalence and frequency

sample_data(physeq)$is.neg <- sample_data(physeq)$Sample_or_Control == "negative_control"
contamdf.prev <- isContaminant(physeq, method="combined",conc="quant_reading",neg="is.neg")
table(contamdf.prev$contaminant)

# Create the decontamed phyloseq object (physeq_nc)

physeq_nc<-prune_taxa(!contamdf.prev$contaminant,physeq)
physeq_nc

# Export the taxonomy table, ASV table, and rooted tree from the decontamed phyloseq object back into QIIME2
# You don't need to export the metadata from the phyloseq object, you can just use the original one
# These will be used to calculate alpha and beta diversity metrics in QIIME2

# Export taxonomy table

tax<-as(tax_table(physeq_nc),"matrix")
tax_cols <- colnames(tax)
tax<-as.data.frame(tax)
tax$taxonomy<-do.call(paste, c(tax[tax_cols], sep=";"))
for(co in tax_cols) tax[co]<-NULL
write.table(tax, "tax_decontam.txt", quote=FALSE, col.names=FALSE, sep="\t")

# Export ASV table as a biom table

otu<-as(otu_table(physeq_nc),"matrix")
otu_biom<-make_biom(data=otu)
write_biom(otu_biom,"ASV_table_decontam.biom")

# Export rooted tree as a .tree file

tree.seq = phy_tree(physeq_nc)
ape::write.tree(tree.seq, file = "rooted_tree_decontam.tree")
